@@ -1,19 +1,22 @@
 package Test::Magpie;
 BEGIN {
-  $Test::Magpie::VERSION = '0.01';
+  $Test::Magpie::VERSION = '0.02';
 }
 # ABSTRACT: Spy on objects to achieve test doubles (mock testing)
 use strict;
 use warnings;
 
+use aliased 'Test::Magpie::Inspect';
 use aliased 'Test::Magpie::Mock';
 use aliased 'Test::Magpie::Spy';
 use aliased 'Test::Magpie::When';
 
 use Moose::Util qw( find_meta ensure_all_roles );
+use MooseX::Params::Validate;
+use Test::Magpie::Types Mock => { -as => 'MockType' };
 
 use Sub::Exporter -setup => {
-    exports => [qw( mock when verify )]
+    exports => [qw( inspect mock when verify )]
 };
 
 sub verify {
@@ -28,10 +31,19 @@ sub mock {
 }
 
 sub when {
-    my $mock = shift;
+    my ($mock) = pos_validated_list(\@_,
+        { isa => MockType }
+    );
     return When->new(mock => $mock);
 }
 
+sub inspect {
+    my ($mock) = pos_validated_list(\@_,
+        { isa => MockType }
+    );
+    return Inspect->new(mock => $mock);
+}
+
 1;
 
 
@@ -130,7 +142,7 @@ documentation for how to fully specify the stub.
 
 =head1 AUTHOR
 
-Oliver Charles
+  Oliver Charles
 
 =head1 COPYRIGHT AND LICENSE
 
