@@ -1,18 +1,47 @@
 package Test::Magpie::ArgumentMatcher;
 BEGIN {
-  $Test::Magpie::ArgumentMatcher::VERSION = '0.01';
+  $Test::Magpie::ArgumentMatcher::VERSION = '0.02';
 }
 # ABSTRACT: Various templates to catch arguments
 
 use strict;
 use warnings;
 
+use Test::Magpie::Util match => { -as => '_match' };
+use Set::Object qw( set );
+
 use Sub::Exporter -setup => {
-    exports => [qw( anything )],
+    exports => [
+        qw( anything hash custom_matcher ),
+        set => sub { \&_set }
+    ],
 };
 
 sub anything {
-    bless sub { return (1,()) }, __PACKAGE__;
+    bless sub { return () }, __PACKAGE__;
+}
+
+sub hash {
+    my (%template) = @_;
+    bless sub {
+        my %hash = @_;
+        for (keys %template) {
+            if (my $v = delete $hash{$_}) {
+                return unless _match($v, $template{$_});
+            }
+            else {
+                return;
+            }
+        }
+        return %hash;
+    }, __PACKAGE__;
+}
+
+sub _set {
+    my ($take) = set(@_);
+    bless sub {
+        return set(@_) == $take ? () : undef;
+    }, __PACKAGE__;
 }
 
 sub match {
@@ -20,6 +49,13 @@ sub match {
     return $self->(@input);
 }
 
+sub custom_matcher {
+    my $test = shift;
+    bless sub {
+        $test->(@_) ? () : undef
+    }, __PACKAGE__;
+}
+
 1;
 
 
@@ -83,7 +119,7 @@ one. You are, however, welcome to use them before.
 
 =head1 AUTHOR
 
-Oliver Charles
+  Oliver Charles
 
 =head1 COPYRIGHT AND LICENSE
 
