@@ -1,13 +1,16 @@
 package Test::Magpie::Util;
 BEGIN {
-  $Test::Magpie::Util::VERSION = '0.01';
+  $Test::Magpie::Util::VERSION = '0.02';
 }
 # ABSTRACT: Utilities used by Test::Magpie
 use strict;
 use warnings;
 
+use aliased 'Test::Magpie::ArgumentMatcher';
+use Scalar::Util qw( blessed );
+
 use Sub::Exporter -setup => {
-    exports => [qw( extract_method_name )],
+    exports => [qw( extract_method_name match )],
 };
 
 sub extract_method_name {
@@ -16,6 +19,13 @@ sub extract_method_name {
     return $method;
 }
 
+sub match {
+    my ($a, $b) = @_;
+    return blessed($a)
+        ? (ref($a) eq ref($b) && $a == $b)
+        : $a ~~ $b;
+}
+
 1;
 
 
@@ -29,16 +39,20 @@ __END__
 
 Test::Magpie::Util - Utilities used by Test::Magpie
 
-=head1 METHODS
+=head1 FUNCTIONS
 
 =head2 extract_method_name
 
 Internal. From a fully qualified method name such as Foo::Bar::baz, will return
 just the method name (in this example, baz).
 
+=head2 match
+
+Internal. Match 2 values for equality
+
 =head1 AUTHOR
 
-Oliver Charles
+  Oliver Charles
 
 =head1 COPYRIGHT AND LICENSE
 
